#!/usr/bin/python

#
#	Grayscale image converter for mk90
#

from PIL import Image
import sys

header = bytes([0xA0, 0x00, 0x0E, 0x01, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0xC4, 0x15, 0x02, 0x02, 0xC3, 0x15, 0xE0, 0x01, 0x14, 0x0A, 0xC2, 0x7E, 0xDF, 0x15, 0x02, 0x02, 0x00, 0xE8, 0xDF, 0x15, 0xC6, 0x82, 0x02, 0xE8, 0x17, 0x8D, 0xE0, 0x00, 0xC5, 0x55, 0x08, 0x00, 0x49, 0x11, 0xDF, 0x15, 0xA0, 0x00, 0x16, 0xE8, 0xCA, 0x09, 0xDF, 0x15, 0x00, 0x00, 0x10, 0xE8, 0xCA, 0x09, 0xDF, 0x15, 0x90, 0x00, 0x10, 0xE8, 0xCA, 0x09, 0xDF, 0x0B, 0x16, 0xE8, 0xCA, 0x09, 0xC4, 0x15, 0x30, 0x23, 0xC3, 0x15, 0x90, 0x00, 0xDF, 0x15, 0xD0, 0x00, 0x16, 0xE8, 0xCA, 0x09, 0xC5, 0x45, 0x08, 0x00, 0x49, 0x11, 0xCA, 0x09, 0xD3, 0x97, 0x10, 0xE8, 0xCA, 0x09, 0x04, 0x7F, 0xDF, 0x0B, 0x16, 0xE8, 0xCA, 0x09, 0xE6, 0x15, 0xE0, 0x00, 0xE6, 0x15, 0x90, 0x00, 0x02, 0x00, 0xDF, 0x15, 0xFC, 0x00, 0x14, 0xE8, 0xDF, 0x15, 0xE8, 0x01, 0x12, 0xE8, 0x1F, 0x8A, 0x16, 0xE8, 0xDF, 0x8B, 0x14, 0xE8, 0xFD, 0x80, 0x1F, 0x8A, 0x16, 0xE8, 0xDF, 0x17, 0xC6, 0x00, 0x00, 0xE8, 0xDF, 0x65, 0xC0, 0x03, 0xC6, 0x00, 0xDF, 0x27, 0xC6, 0x00, 0x00, 0x02, 0xF1, 0x07, 0xDF, 0x15, 0x02, 0x02, 0xC6, 0x00, 0xED, 0x01, 0x02, 0x02])

im = Image.open(sys.argv[1])
colorCount = im.getextrema()[1]

if im.width!=120 or im.height!=64 or im.getbands()[0]!="P" or colorCount not in range(1,10):
	print("Image must be 120x64 grayscale with 2-10 clors")
	sys.exit(-1)	

pix = im.load()

outfile = [bytearray() for x in range(colorCount)]
	
for y in range(0, round(im.height/2)):
	x = 0
	while x < im.width:
		currentWord = [0]*(colorCount)
		for i in range(8):
			currentWord = [(x << 1 & 0xFFFF) for x in currentWord]
			currentPixel = pix[x+i, y+im.height/2]
			for k in range(currentPixel,colorCount):
				currentWord[k] |= 0x0100
			currentPixel = pix[x+i, y]
			for k in range(currentPixel,colorCount):
				currentWord[k] |= 0x0001
		for k in range(colorCount):
			outfile[k].append(currentWord[k] & 0xFF)
			outfile[k].append((currentWord[k] >> 8) & 0xFF)
		x += 8

with open(sys.argv[1].split(".")[0]+'.bin', 'wb') as f:
	f.write(header)
	f.seek(512)
	lastColor = (colorCount-1)*960+2+512
	f.write(bytes([lastColor & 0xFF, (lastColor >> 8) & 0xFF]))
	for color in outfile:
		f.write(color)
	f.close()